OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Manylion",
    "Rename" : "Ailenwi",
    "Move" : "Symud",
    "Delete" : "Dileu",
    "New" : "Newydd",
    "New folder" : "Ffolder newydd",
    "Grid view" : "Golwg grid",
    "List view" : "Golwg rhestr",
    "Cancel" : "Diddymu",
    "Recent" : "Diweddar",
    "Import" : "Mewnforio",
    "Export" : "Allforio",
    "Recently added" : "Ychwanegwyd yn ddiweddar",
    "Last modified" : "Newidiwyd diwethaf",
    "Title" : "Teitl",
    "Link" : "Dolen",
    "Tags" : "Tagiau",
    "Notes" : "Nodiadau",
    "Owner" : "Owner",
    "Share link" : "Rhannu dolen",
    "Copy link" : "Copïo dolen",
    "Select" : "Select",
    "Folder" : "Plygell",
    "Save" : "Cadw"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
